California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 72 - REFERENDUM PETITION TO OVERTURN AMENDMENTS TO HEALTH CARE COVERAGE REQUIREMENTS. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261319 | YES ON 72, SAVE YOUR HEALTHCARE: SUPPORTED BY NURSES, DOCTORS, UNIONS, CONCUMER ADVOCATES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1260240 | CALIFORNIANS AGAINST GOVERNMENT RUN HEALTHCARE, A COMMITTEE AGAINST PROPOSITION 72, WITH MAJOR FUNDING BY RESTAURANTS AND RETAILERS | OPPOSE